@@ -83,7 +83,7 @@ def get_pdf_help(missing_libs=""):
 
     2. Next, install weasyprint python modules using pip.
 
-        pip install xml2rfc[pdf]
+        pip install "xml2rfc[pdf]"
 
     3. Finally, install the required fonts:
        * Download latest fonts from xml2rfc-fonts.
@@ -198,6 +198,8 @@ def main():
                            help='outputs formatted text to file, unpaginated (only v2 input)')
     formatgroup.add_argument('--expand', action='store_true',
                            help='outputs XML to file with all references expanded')
+    formatgroup.add_argument('--use-bib', action='store_true',
+                           help='update all datatracker references with bib.ietf.org')
     formatgroup.add_argument('--v2v3', action='store_true',
                            help='convert vocabulary version 2 XML to version 3')
     formatgroup.add_argument('--preptool', action='store_true',
@@ -284,6 +286,10 @@ def main():
                             help='More easily do line breaks after hyphens in table cells to give a more compact table')
     textoptions.add_argument('--table-borders', default='full', choices=['full', 'light', 'minimal', 'min', ],
                             help='The style of table borders to use for text output; one of full/light/minimal')
+    textoptions.add_argument('--rfc-html-archive-url', default="https://www.rfc-editor.org/rfc/",
+                           help='URL for HTML file archive of RFCs')
+    textoptions.add_argument('--id-html-archive-url', default="https://www.ietf.org/archive/id/",
+                           help='URL for HTML file archive Internet-Drafts')
 
     htmloptions = optionparser.add_argument_group('Html Format Options')
     htmloptions.add_argument('--css', default=None, metavar="FILE",
@@ -291,11 +297,11 @@ def main():
     htmloptions.add_argument('--external-css', action='store_true', default=False,
                            help='place css in external files')
     htmloptions.add_argument('--no-external-css', dest='external_css', action='store_false',
-                           help='place css in external files')
+                           help="don't place css in external files")
     htmloptions.add_argument('--external-js', action='store_true', default=False,
                            help='place js in external files')
     htmloptions.add_argument('--no-external-js', dest='external_js', action='store_false',
-                           help='place js in external files')
+                           help="don't place js in external files")
     htmloptions.add_argument('--rfc-base-url', default="https://www.rfc-editor.org/rfc/",
                            help='Base URL for RFC links')
     htmloptions.add_argument('--id-base-url', default="https://datatracker.ietf.org/doc/html/",
@@ -341,7 +347,6 @@ def main():
     # Some additional values not exposed as options
     options.doi_base_url = "https://doi.org/"
     options.no_css = False
-    options.image_svg = False
 
     # --- Set default values ---------------------------------
 
@@ -452,7 +457,7 @@ def main():
             options.output_path = options.basename
             options.basename = None
     #
-    num_formats = len([ o for o in [options.raw, options.text, options.nroff, options.html, options.expand, options.v2v3, options.preptool, options.info, options.pdf, options.unprep ] if o])
+    num_formats = len([ o for o in [options.raw, options.text, options.nroff, options.html, options.expand, options.use_bib, options.v2v3, options.preptool, options.info, options.pdf, options.unprep ] if o])
     if num_formats > 1 and (options.filename or options.output_filename):
         sys.exit('Cannot use an explicit output filename when generating more than one format, '
                  'use --path instead.')
@@ -658,6 +663,15 @@ def main():
             options.output_filename = None
 
         # --- End of legacy formatter invocations ---
+        if options.use_bib:
+            xmlrfc = parser.parse(remove_comments=False, quiet=True, normalize=False, strip_cdata=False, add_xmlns=True)
+            filename = options.output_filename
+            if not filename:
+                filename = basename + '.bib.xml'
+                options.output_filename = filename
+            expander = xml2rfc.DatatrackerToBibConverter(xmlrfc, options=options, date=options.date)
+            expander.write(filename)
+            options.output_filename = None
 
         if options.expand and not options.legacy:
             xmlrfc = parser.parse(remove_comments=False, quiet=True, normalize=False, strip_cdata=False, add_xmlns=True)
